"use strict";

var path = require('path');

var fs = require('fs'); // ./button-next => ./Button-next


var upperCaseFirstChar = function upperCaseFirstChar(str) {
  return str.charAt(0).toUpperCase() + str.slice(1);
}; // ./Button-Next => ./ButtonNext


var formatToPascalCase = function formatToPascalCase(str) {
  return str.split('-').map(function (subStr) {
    return upperCaseFirstChar(subStr);
  }).join('');
};

module.exports = function (pathName, dts, options) {
  if (options === void 0) {
    options = {};
  }

  var componentsPath = path.resolve('dist', pathName);
  options.forcePascalCaseFormat = options.forcePascalCaseFormat || false;

  if (fs.existsSync(componentsPath)) {
    fs.readdirSync(componentsPath).map(function (name) {
      return [name, path.resolve(componentsPath, name)];
    }).filter(function (_ref) {
      var absolutePath = _ref[1];
      return fs.lstatSync(absolutePath).isDirectory() && fs.readdirSync(absolutePath).includes('index.js');
    }).map(function (_ref2) {
      var name = _ref2[0],
          absolutePath = _ref2[1];
      var componentPath = path.relative('./', absolutePath);
      name = options.forcePascalCaseFormat ? formatToPascalCase(name) : name;
      var files = [{
        path: "./" + name + ".js",
        source: "module.exports = require('./" + componentPath + "');\n"
      }];

      if (dts) {
        var declarationFile = {
          path: "./" + name + ".d.ts",
          source: "export * from './" + componentPath + "';\n"
        };
        files.push(declarationFile);
      }

      return files;
    }).map(function (files) {
      return files.forEach(function (_ref3) {
        var path = _ref3.path,
            source = _ref3.source;
        fs.writeFileSync(path, source);
      });
    });
  }
};